@@ -12,10 +12,10 @@ test_that("test that transformation safety checks are in place", {
   a <- tibble(variable = "A", ROI = 1:5, value = runif(5), sigma = 0.1, data_type = "temp")
   b <- tibble(variable = "B", ROI = 1:5, value = rnorm(5), sigma = 0.2, data_type = "temp")
   expect_equal(
-    spread_data(bind_rows(a,b)) %>% select(ROI, A, B, `A sigma`, `B sigma`) %>% arrange(ROI),
+    spread_data(bind_rows(a,b)) %>% select("ROI", "A", "B", "A sigma", "B sigma") %>% arrange(ROI),
     full_join(
-      a %>% rename(A = value, `A sigma` = sigma) %>% select(-data_type, -variable),
-      b %>% rename(B = value, `B sigma` = sigma) %>% select(-data_type, -variable),
+      a %>% rename(A = value, `A sigma` = sigma) %>% select(-"data_type", -"variable"),
+      b %>% rename(B = value, `B sigma` = sigma) %>% select(-"data_type", -"variable"),
       by = "ROI"
-    ) %>% select(ROI, A, B, `A sigma`, `B sigma`) %>% arrange(ROI))
+    ) %>% select("ROI", "A", "B", "A sigma", "B sigma") %>% arrange(ROI))
 })
\ No newline at end of file
